@@ -1,3 +1,4 @@
+from datetime import datetime
 from credmgr.models.utils import resolveUser
 
 
@@ -17,10 +18,10 @@ class BaseModel(object):
         if self._nameAttr and self._canFetchByName:
             setattr(self, self._nameAttr, name)
 
-    def __getattr__(self, attribute):
+    def __getattr__(self, attribute): # pragma: no cover
         '''Return the value of `attribute`.'''
         if not attribute.startswith('_') and not self._fetched:
-            self.fetch()
+            self._fetch()
             return getattr(self, attribute)
         raise AttributeError(f'{self.__class__.__name__!r} object has no attribute {attribute!r}')
 
@@ -36,7 +37,7 @@ class BaseModel(object):
             data[self._fetchNameAttr] = name
         self.__dict__ = self._credmgr.post(f'{self._path}/{self._getByNamePath}', data=data).__dict__
 
-    def fetch(self, byName=False):
+    def _fetch(self, byName=False):
         if byName and self._canFetchByName:
             self.getByName(getattr(self, self._nameAttr))
         else:
@@ -51,27 +52,27 @@ class BaseModel(object):
     def toDict(self):
         result = {}
 
-        for attr, _ in self._attrTypes.items():
-            attr = ''.join(attr.split('_')[:1] + [i.capitalize() for i in attr.split('_')[1:]])
-            value = getattr(self, attr)
-            if isinstance(value, list):
-                result[attr] = list(map(lambda x: x.toDict() if hasattr(x, 'toDict') else x, value))
-            elif hasattr(value, 'toDict'):
-                result[attr] = value.toDict()
-            elif isinstance(value, dict):
-                result[attr] = dict(map(lambda item: (item[0], item[1].toDict()) if hasattr(item[1], 'toDict') else item, value.items()))
-            else:
-                result[attr] = value
-        if issubclass(type(self), dict):
+        for exportAttr, _ in self._attrTypes.items():
+            attr = ''.join(exportAttr.split('_')[:1] + [i.capitalize() for i in exportAttr.split('_')[1:]])
+            value = getattr(self, attr, None)
+            if value:
+                if isinstance(value, list):
+                    result[exportAttr] = list(map(lambda x: x.toDict() if hasattr(x, 'toDict') else x, value))
+                elif hasattr(value, 'toDict'):
+                    result[exportAttr] = value.toDict()
+                elif isinstance(value, dict):
+                    result[exportAttr] = dict(map(lambda item: (item[0], item[1].toDict()) if hasattr(item[1], 'toDict') else item, value.items()))
+                elif isinstance(value, datetime):
+                    result[exportAttr] = value.astimezone().strftime(self._credmgr.config.dateFormat)
+                else:
+                    result[exportAttr] = value
+        if issubclass(type(self), dict): # pragma: no cover
             for key, value in self.items():
                 result[key] = value
         return result
 
-    def __repr__(self):
-        ownerRepr = ''
-        if hasattr(self, 'owner') and self.owner is not None:
-            ownerRepr = f', owner={self.owner.username!r}'
-        return f'<{self.__class__.__name__} id={self.id}, {self._nameAttr}={getattr(self, self._nameAttr)!r}{ownerRepr}>'
+    def __repr__(self): # pragma: no cover
+        return f'<{self.__class__.__name__} id={self.id}, {self._nameAttr}={getattr(self, self._nameAttr)!r}>'
 
     def __eq__(self, other):
         '''Returns true if both objects are equal'''
