@@ -39,13 +39,13 @@ class Serializer(object):
         try:
             from dateutil.parser import parse
             return parse(string)
-        except ImportError:
+        except ImportError: # pragma: no cover
             return string
-        except ValueError:
+        except ValueError: # pragma: no cover
             raise SerializerException(f"Failed to parse `{string}` as datetime object")
 
     @staticmethod
-    def deserializeDate(string):
+    def deserializeDate(string): # pragma: no cover
         '''Deserializes string to date.
 
         :param string: str.
@@ -65,7 +65,7 @@ class Serializer(object):
 
         :return: object.
         '''
-        return value
+        return value # pragma: no cover
 
     @staticmethod
     def deserializePrimitive(data, objectType):
@@ -78,9 +78,9 @@ class Serializer(object):
         '''
         try:
             return objectType(data)
-        except UnicodeEncodeError:
+        except UnicodeEncodeError: # pragma: no cover
             return str(data)
-        except TypeError:
+        except TypeError: # pragma: no cover
             return data
 
     def deserialize(self, response):
@@ -94,7 +94,7 @@ class Serializer(object):
         if isinstance(data, list) and all([i['resource_type'] == data[0]['resource_type'] for i in data]):
             if data:
                 resourceType = f'list[{data[0]["resource_type"]}]'
-            else:
+            else: # pragma: no cover
                 return data
         else:
             resourceType = data.get('resource_type', 'dict')
@@ -127,9 +127,9 @@ class Serializer(object):
 
         if objectType in self.primitiveTypes:
             return self.deserializePrimitive(data, objectType)
-        elif objectType == object:
+        elif objectType == object: # pragma: no cover
             return self.deserializeObject(data)
-        elif objectType == datetime.date:
+        elif objectType == datetime.date: # pragma: no cover
             return self.deserializeDate(data)
         elif objectType == datetime.datetime:
             return self.deserializeDatatime(data)
@@ -138,7 +138,7 @@ class Serializer(object):
         else:
             return self.__deserializeModel(data, objectType)
 
-    def __hasattr(self, object, name):
+    def __hasattr(self, object, name): # pragma: no cover
         return name in object.__class__.__dict__
 
     def __deserializeModel(self, data, objectType):
@@ -149,7 +149,7 @@ class Serializer(object):
         :return: model object.
         '''
 
-        if not objectType._attrTypes:
+        if not objectType._attrTypes: # pragma: no cover
             return data
 
         kwargs = {}
@@ -161,11 +161,11 @@ class Serializer(object):
                     kwargs[snakeToCamel(attr)] = self.__deserialize(value, attrType)
         try:
             instance = objectType(self._credmgr, **kwargs)
-        except TypeError:
+        except TypeError: # pragma: no cover
             for key, value in kwargs.items():
                 setattr(objectType, key, value)
             instance = objectType
-        if isinstance(instance, dict) and objectType._attrTypes is not None and isinstance(data, dict):
+        if isinstance(instance, dict) and objectType._attrTypes is not None and isinstance(data, dict):  # pragma: no cover
             for key, value in data.items():
                 if key not in objectType._attrTypes:
                     instance[key] = value
